@@ -1,8 +1,8 @@
 import os
-import random
 import tempfile
-import keras
 from unittest import TestCase
+import numpy as np
+from keras_gpt_2.backend import keras
 from keras_gpt_2 import get_model, get_custom_objects
 
 
@@ -16,7 +16,7 @@ class TestModel(TestCase):
             n_head=12,
             n_layer=12,
         )
-        model_path = os.path.join(tempfile.gettempdir(), 'test_gpt_2_%f.h5' % random.random())
+        model_path = os.path.join(tempfile.gettempdir(), 'test_gpt_2_%f.h5' % np.random.random())
         model.save(model_path)
         model = keras.models.load_model(model_path, custom_objects=get_custom_objects())
         model.summary()
@@ -30,7 +30,7 @@ class TestModel(TestCase):
             n_layer=12,
             fixed_input_shape=True,
         )
-        model_path = os.path.join(tempfile.gettempdir(), 'test_gpt_2_%f.h5' % random.random())
+        model_path = os.path.join(tempfile.gettempdir(), 'test_gpt_2_%f.h5' % np.random.random())
         model.save(model_path)
         model = keras.models.load_model(model_path, custom_objects=get_custom_objects())
         model.summary()
